test

package
v0.0.0-...-ec844c3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 25, 2026 License: Apache-2.0 Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func RequireNilErr

func RequireNilErr(t Controller, err error)

func RequireNilErrf

func RequireNilErrf(t Controller, err error, format string, parameters ...any)

Types

type Context

type Context interface {
	Controller
	context.Context
}

func NewContext

func NewContext(controller Controller) Context

func WithContext

func WithContext(parentCtx context.Context, controller Controller) Context

type Controller

type Controller interface {
	Cleanup(func())
	Errorf(format string, args ...any)
	Fatalf(format string, args ...any)
	FailNow()
}

Directories

Path Synopsis
Package mock is a generated GoMock package.
Package mock is a generated GoMock package.
Deprecated: this suite of integration utils is deprecated and should be avoided Integration tests should be updated to reflect the latest standards.
Deprecated: this suite of integration utils is deprecated and should be avoided Integration tests should be updated to reflect the latest standards.
lab

Jump to