Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func RequireNilErr ¶
func RequireNilErr(t Controller, err error)
func RequireNilErrf ¶
func RequireNilErrf(t Controller, err error, format string, parameters ...any)
Types ¶
type Context ¶
type Context interface {
Controller
context.Context
}
func NewContext ¶
func NewContext(controller Controller) Context
func WithContext ¶
func WithContext(parentCtx context.Context, controller Controller) Context
Directories
¶
| Path | Synopsis |
|---|---|
|
Package mock is a generated GoMock package.
|
Package mock is a generated GoMock package. |
|
Deprecated: this suite of integration utils is deprecated and should be avoided Integration tests should be updated to reflect the latest standards.
|
Deprecated: this suite of integration utils is deprecated and should be avoided Integration tests should be updated to reflect the latest standards. |
|
lab
|
|
Click to show internal directories.
Click to hide internal directories.